@@ -43,7 +43,7 @@ private Q_SLOTS:
 
         KIMAP::Session session(QStringLiteral("127.0.0.1"), 5989);
 
-        KIMAP::ListJob *job = new KIMAP::ListJob(&session);
+        auto *job = new KIMAP::ListJob(&session);
         job->setIncludeUnsubscribed(true);
         QVERIFY(job->exec());
 
