@@ -18,7 +18,8 @@ class CloseJobPrivate : public JobPrivate
 {
 public:
     CloseJobPrivate(Session *session, const QString &name) : JobPrivate(session, name) { }
-    ~CloseJobPrivate() { }
+
+    quint64 highestModSeq = 0;
 };
 }
 
@@ -29,12 +30,25 @@ CloseJob::CloseJob(Session *session)
 {
 }
 
-CloseJob::~CloseJob()
-{
-}
-
 void CloseJob::doStart()
 {
     Q_D(CloseJob);
     d->tags << d->sessionInternal()->sendCommand("CLOSE");
 }
+
+quint64 CloseJob::newHighestModSeq() const
+{
+    Q_D(const CloseJob);
+    return d->highestModSeq;
+}
+
+void CloseJob::handleResponse(const Response &response)
+{
+    Q_D(CloseJob);
+
+    if (response.responseCode.size() >= 2 && response.responseCode[0].toString() == "HIGHESTMODSEQ") {
+        d->highestModSeq = response.responseCode[1].toString().toULongLong();
+    }
+
+    Job::handleErrorReplies(response);
+}
