@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2009 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2009 Kevin Ottens <ervin@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIMAP_SELECTJOB_H
@@ -23,6 +10,7 @@
 #include "kimap_export.h"
 
 #include "job.h"
+#include "fetchjob.h"
 
 namespace KIMAP
 {
@@ -30,6 +18,7 @@ namespace KIMAP
 class Session;
 struct Response;
 class SelectJobPrivate;
+class ImapSet;
 
 class KIMAP_EXPORT SelectJob : public Job
 {
@@ -90,6 +79,48 @@ public:
      */
     Q_REQUIRED_RESULT bool condstoreEnabled() const;
 
+    /**
+     * Set Quick Resynchronization parameters.
+     *
+     * Requires that the server supports the QRESYNC extension as defined in RFC5162
+     * and the QRESYNC extension has been enabled via EnableJob.
+     *
+     * Using this option implies enabling CONDSTORE.
+     *
+     * @param lastUidvalidity Last UIDValidity value known to the client
+     * @param lastModseq Last modification sequence number known to the client
+     * @param knownUids List of all UIDs known to the client (optional).
+     *
+     * @see KIMAP::EnableJob
+     */
+    void setQResync(qint64 lastUidvalidity, quint64 lastModseq, const ImapSet &knownUids = ImapSet{});
+
+Q_SIGNALS:
+    /**
+     * Emitted when the server provides a list of UIDs that have vanished since last sync.
+     *
+     * This feature requires that the QRESYNC parameters have been provided
+     * to the SELECT command. This signal may not be emitted if no messages
+     * have been expunged since the last check.
+     *
+     * @see setQResync()
+     * @since 5.16
+     */
+    void vanished(const KIMAP::ImapSet &set);
+
+    /**
+     * Emitted when the server provides a list of messages that have changed or appeared
+     * in the mailbox since the last sync.
+     *
+     * This feature requires that the QRESYNC parameters have been provided
+     * to the SELECT command. The signal may not be emitted if no messages
+     * have been modified or appended to the mailbox.
+     *
+     * @see setQResync()
+     * @since 5.16
+     */
+    void modified(const QMap<qint64, KIMAP::Message> &messages);
+
 protected:
     void doStart() override;
     void handleResponse(const Response &response) override;
